from loaderio.resources.client import Client

class Results(Client):
	"""

	"""
	def __init__(self, api_key):
		Client.__init__(self, api_key)
		pass

	def list(self):
		pass

	def get_result(self, results_id):
		pass